document.addEventListener("DOMContentLoaded", () => {
  const form = document.getElementById("lookupForm");
  const loader = document.getElementById("loader");
  const results = document.getElementById("results");
  const error = document.getElementById("error");

  const displayResults = (data) => {
    document.getElementById("country").textContent = data.country;
    document.getElementById("city").textContent = data.city;
    document.getElementById("region").textContent = data.region;
    document.getElementById("timezone").textContent = data.timezone;
    document.getElementById("isp").textContent = data.isp;

    loader.classList.add("hidden");
    results.classList.remove("hidden");
    error.classList.add("hidden");
  };

  const showError = () => {
    loader.classList.add("hidden");
    results.classList.add("hidden");
    error.classList.remove("hidden");
  };

  form.addEventListener("submit", async (e) => {
    e.preventDefault();

    const ipInput = document.getElementById("ipInput");
    const ipAddress = ipInput.value.trim();

    if (!ipAddress) return;

    loader.classList.remove("hidden");
    results.classList.add("hidden");
    error.classList.add("hidden");

    try {
      const response = await fetch(`https://ipapi.co/${ipAddress}/json/`);
      const data = await response.json();

      if (data.error) {
        throw new Error("Invalid IP address");
      }

      displayResults({
        country: data.country_name || "N/A",
        city: data.city || "N/A",
        region: data.region || "N/A",
        timezone: data.timezone || "N/A",
        isp: data.org || "N/A",
      });
    } catch (err) {
      showError();
    }
  });
});
